@@ -11,7 +11,7 @@ plot(t, y,
      legend='t^2*exp(-t^2)',
      axis=[0, 3, -0.05, 0.6],
      title='My First Easyviz Demo',
-     hardcopy='tmp1.eps',
+     savefig='tmp1.eps',  # or hardcopy='tmp1.eps'
      show=True)
 
 raw_input('Press Return key to quit: ')
