@@ -15,13 +15,14 @@ plot(t, y1, 'r-', t, y2, 'bo',
      axis=[0, 4, -0.1, 0.6],
      legend=('t^2*exp(-t^2)', 't^4*exp(-t^2)'),
      title='Plotting two curves in the same plot',
-     hardcopy='tmp2.eps')
+     savefig='tmp2.eps')
 
 # grab the backend plotting object and work with the plotting
 # program directly:
 
-g = get_backend()
-if g.__class__.__name__ == 'Gnuplot':
+if backend == 'gnuplot':
+    g = get_backend()
+    #g.__class__.__name__ == 'Gnuplot'
     # g is a Gnuplot object, work with Gnuplot commands directly:
     g('set label "global maximum" at 0.1,0.5 font "Times,18"')
     g('set arrow from 0.5,0.48 to 0.98,0.37 linewidth 2')
