@@ -45,6 +45,7 @@ import os
 import sys
 import operator
 import string
+import time
 
 # Update Gnuplot.GnuplotOpts according to scitools.cfg
 _update_from_config_file(Gnuplot.GnuplotOpts.__dict__, section='gnuplot')
@@ -657,11 +658,13 @@ class GnuplotBackend(BaseClass):
             kwargs = {'title': item.getp('legend'),
                       'with': withstring,
                       'using': '1:($2)'}
+            
             data = Gnuplot.Data(arrayconverter(x),
                                 arrayconverter(y), 
                                 **kwargs)
         return data
 
+        
     def _add_filled_line(self, item):
         """Add a 2D or 3D filled curve."""
         if DEBUG:
@@ -1100,7 +1103,7 @@ class GnuplotBackend(BaseClass):
         #self._g('set size 1.0, 1.0')
         #self._g('set origin 0.0, 0.0')
         self._g('unset multiplot')
-        self._g('set missing "nan"')
+        self._g('set datafile missing "nan"')
         
         self._set_figure_size(fig)
 
@@ -1121,6 +1124,8 @@ class GnuplotBackend(BaseClass):
                 size = 1/ncolumns, 1/nrows
                 self._g('set origin %s,%s' % (origin[0], origin[1]))
                 self._g('set size %s,%s' % (size[0], size[1]))
+            loc = self._loc_syntax(ax)
+            self._g('set key ' + loc)
             plotitems = ax.getp('plotitems')
             plotitems.sort(self._cmpPlotProperties)
             for item in plotitems:
@@ -1178,6 +1183,11 @@ class GnuplotBackend(BaseClass):
                 for data in gdata[1:]:
                     self._g.replot(data)
 
+            # Gnuplot may give thread error for many plot items,
+            # let it wait a bit when there are many curves in a plot
+            if len(plotitems) > 6:
+                time.sleep(0.3)
+                
         if sys.platform == 'win32':
             # Since os.mkfifo is not available on the Windows platform, we
             # store a reference to the gnuplot data so that the temporary
@@ -1197,6 +1207,40 @@ class GnuplotBackend(BaseClass):
                 debug(self)
             pass
 
+    def _loc_syntax(self, ax):
+        """
+        Change from (Matplotlib-inspired) syntax of loc
+        specification of legends to Gnuplot "key" syntax.
+        """
+        try:
+            loc = ax.getp('legend_loc')
+        except KeyError:
+            loc = 'best'
+
+        mpl2gp = {
+            'upper right': 'right top',
+            'upper left': 'left top',
+            'lower left': 'left bottom',
+            'lower right': 'right bottom',
+            'center left': 'left center',
+            'center right': 'right center',
+            'lower center': 'center bottom',
+            'upper center': 'center top',
+            'best': 'right top', # default
+            'right': 'right top',
+            'center': 'center center'}
+        loc = mpl2gp[loc]
+        
+        try:
+            fancybox = ax.getp('legend_fancybox')
+        except KeyError:
+            fancybox = False
+
+        if fancybox:
+            loc = loc + ' box'
+        return loc
+        
+
     def cleanup(self):
         """Clean up data."""
         try:
@@ -1281,7 +1325,7 @@ class GnuplotBackend(BaseClass):
                     kwargs['mode'] = 'eps'
                 else:
                     self._g('set term postscript %s %s' % \
-                            (orientation,colortype))
+                            (orientation, colortype))
                     kwargs['mode'] = orientation
             elif terminal == 'png':
                 self._g('set term png')
@@ -1339,7 +1383,7 @@ class GnuplotBackend(BaseClass):
         orientation = kwargs.get('orientation', None)
         solid = kwargs.get('solid', False)
         fontname = kwargs.get('fontname', 'Helvetica')
-        fontsize = kwargs.get('fontsize', 14)
+        fontsize = kwargs.get('fontsize', 20)
         
         keyw = {'filename': filename, 'terminal': terminal}
         if terminal == 'postscript':
@@ -1362,6 +1406,7 @@ class GnuplotBackend(BaseClass):
             setterm.append(enhanced and 'enhanced' or 'noenhanced')
             setterm.append(color and 'color' or 'monochrome')
             setterm.append(solid and 'solid' or 'dashed')
+            setterm.append(' dashlength 3 linewidth 1.2 ')
             setterm.append('"%s"' % fontname)
             setterm.append('%s' % fontsize)
         elif terminal == 'png':
@@ -1539,3 +1584,4 @@ class GnuplotBackend(BaseClass):
     
 plt = GnuplotBackend()  # create backend instance
 use(plt, globals())     # export public namespace of plt to globals()
+backend = os.path.splitext(os.path.basename(__file__))[0][:-1]
