@@ -24,7 +24,6 @@ REQUIREMENTS:
 Matplotlib
 
 """
-
 from __future__ import division
 
 from common import *
@@ -41,7 +40,8 @@ import matplotlib.colors
 _update_from_config_file(matplotlib.rcParams, section='matplotlib')
 matplotlib.interactive(True)
 from matplotlib.font_manager import fontManager, FontProperties
-import pylab
+#import pylab
+import matplotlib.pyplot as pylab
 import re
 
 
@@ -397,6 +397,8 @@ class MatplotlibBackend(BaseClass):
 
     def _fix_latex(self, legend):
         """Enclose legend in $$ if latex syntax is detected."""
+        if not matplotlib.rcParams['text.usetex']:
+            return legend
         legend = legend.strip()
         if len(legend) >= 2 and legend[0] != '$' and legend[-1] != '$':
             chars = '\\', '^', '_'
@@ -896,7 +898,16 @@ class MatplotlibBackend(BaseClass):
                     self._g.hold(True)
 
             if legends:
-                self._g.legend()
+                try:
+                    loc = ax.getp('legend_loc')
+                except KeyError:
+                    loc = 'best'
+                try:
+                    fancybox = ax.getp('legend_fancybox')
+                except KeyError:
+                    fancybox = True
+                self._g.legend(loc=loc, fancybox=fancybox)
+
             self._set_axis_props(ax)
                     
         # set back the interactive state in pylab:
@@ -918,7 +929,6 @@ class MatplotlibBackend(BaseClass):
              fontname=Axis._local_prop['fontname'],
              fontsize=Axis._local_prop['fontsize']):
         """Write text at position (x,y) in a curveplot."""
-        # probably:
         self._g.text(x, y, text, family=fontname, size=fontsize)
         
 
@@ -1059,3 +1069,5 @@ use(plt, globals())        # export public namespace of plt to globals()
 # We should close all figure windows on program exit:
 import atexit
 atexit.register(close, 'all')
+
+backend = os.path.splitext(os.path.basename(__file__))[0][:-1]
