@@ -24,7 +24,7 @@ def test_if_module_exists(modulename, msg='',
                   (modulename, msg)
         if raise_exception:
             if msg:
-                print message
+                print msg
                 #print 'The problem arose in ', 
                 debug.trace(frameno=-3)
             raise ImportError(message)
@@ -37,6 +37,12 @@ def test_if_module_exists(modulename, msg='',
                 sys.exit(1)
             else:
                 return False
+    except Exception, e:
+        if msg:
+            print message
+            print 'Got an exception while trying to import %s:\n' % \
+                modulename, e
+
 
 def func_to_method(func, class_, method_name=None):
     """
@@ -54,16 +60,18 @@ def system(command, verbose=True, failure_handling='exit', fake=False):
     Actually, the commands.getstatusoutput function is used on Unix
     systems, and the output from the system command is fetched.
 
-    @param command: operating system command to be executed.
-    @param verbose: False: no output, True: print command prior
-    to execution.
-    @param failure_handling: one of 'exit', 'warning', 'exception',
-    or 'silent'.
-    In case of failure, the output from the command is always displayed.
-    @param fake: if True, the command is printed but not run (for testing).
-    @return: the same as commands.getstatusoutput, i.e.,
-    a boolean failure variable and the output from the command
-    as a string object.
+    ================  ========================================================
+    ================  ========================================================
+    command           operating system command to be executed
+    verbose           False: no output, True: print command prior to execution
+    failure_handling  one of 'exit', 'warning', 'exception', or 'silent'
+                      (in case of failure, the output from the command is 
+                      always displayed)
+    fake              if True, the command is printed but not run (for testing)
+    return value      the same as commands.getstatusoutput, i.e., a boolean 
+                      failure variable and the output from the command as a 
+                      string object
+    ================  ========================================================
     """
     if verbose:
         print 'Running operating system command\n   %s' % command
@@ -102,8 +110,8 @@ def read_cml(option, default=None, argv=sys.argv):
     Search for option (e.g. '-p', '--plotfile') among the command-line
     arguments and return the associated value (the proceeding argument).
     If the option is not found, the default argument is returned
-    as a string (since everything we search for on the command line
-    will be strings).
+    as str(default) (to have a unified behavior in that everything returned
+    from read_cml is a string).
 
     The call::
     
@@ -112,12 +120,14 @@ def read_cml(option, default=None, argv=sys.argv):
     will return a Python object (with the right type) corresponding to
     the value of the object (see the str2obj function).
 
-    @param option: command-line option.
-    @type  option: string.
-    @param default: default value associated with this option.
-    @param argv: list that is scanned for command-line arguments.
-    @return: the item in argv after the option, or default is option
-    is not found.
+    ================  ========================================================
+    ================  ========================================================
+    option            command-line option (str)
+    default           default value associated with the option
+    argv              list that is scanned for command-line arguments
+    return value      the item in argv after the option, or default if option
+                      is not found
+    ================  ========================================================
 
     See the read_cml_func function for reading function expressions
     or function/instance names on the command line and returning
@@ -138,7 +148,8 @@ def str2bool(s):
     """
     Turn a string s, holding some boolean value
     ('on', 'off', 'True', 'False', 'yes', 'no' - case insensitive)
-    into boolean variable. s can also be a boolean. Example::
+    into boolean variable. s can also be a boolean. Example:
+    
     >>> str2bool('OFF')
     False
     >>> str2bool('yes')
@@ -162,16 +173,15 @@ def str2bool(s):
                         (s, type(s)))
     
 
-def str2obj(s, globals=globals(), locals=locals(), debug=False):
+def str2obj(s, globals_=None, locals_=None, debug=False):
     """
     Turn string s into the corresponding object. str2obj is mainly
     used to take a string from a GUI or the command line and
-    create a Python object. For example::
+    create a Python object. For example:
 
     >>> s = str2obj('0.3')
     >>> print s, type(s)
     0.3 <type 'float'>
-
     >>> s = str2obj('(1,8)')
     >>> print s, type(s)
     (1, 8) <type 'tuple'>
@@ -190,16 +200,19 @@ def str2obj(s, globals=globals(), locals=locals(), debug=False):
 
     In this function we first try to see if s is a boolean value,
     using scitools.misc.str2bool. If this does is not successful,
-    we try eval(s), and if it works, we return the resulting object.
-    Otherwise, s is (most probably) a string, so we return s itself.
+    we try eval(s, globals_, locals_), and if it works, we return
+    the resulting object. Otherwise, s is (most probably) a string,
+    so we return s itself. The None value of locals_ and globals_
+    implies using locals() and globals() in this function.
 
-    Examples::
+    Examples:
 
     >>> strings = ('0.3', '5', '[-1,2]', '-1+3j', 'dict(a=1,b=0,c=2)',
     ...            'some string', 'true', 'ON', 'no')
     >>> for s in strings:
     ...     obj = str2obj(s)
     ...     print '"%s" -> %s %s' % (s, obj, type(obj)
+    ...
     "0.3" -> 0.3 <type 'float'>
     "5" -> 5 <type 'int'>
     "[-1,2]" -> [-1, 2] <type 'list'>
@@ -209,6 +222,7 @@ def str2obj(s, globals=globals(), locals=locals(), debug=False):
     "true" -> True <type 'bool'>
     "ON" -> True <type 'bool'>
     "no" -> False <type 'bool'>
+    >>>
     
     If the name of a user defined function, class or instance is
     sent to str2obj, the calling code must also send locals() and
@@ -216,16 +230,16 @@ def str2obj(s, globals=globals(), locals=locals(), debug=False):
     will not know how to "eval" the string and produce the right
     object (user-defined types are unknown inside str2obj unless
     the calling code's globals and locals are provided).
-    Here is an example::
+    Here is an example:
     
     >>> def myf(x):
     ...     return 1+x
-    ... 
+    ...
     >>> class A:
     ...     pass
-    ... 
+    ...
     >>> a = A()
-    >>> 
+    >>>
     >>> s = str2obj('myf')
     >>> print s, type(s)   # now s is simply the string 'myf'
     myf <type 'str'>
@@ -238,22 +252,27 @@ def str2obj(s, globals=globals(), locals=locals(), debug=False):
     <__main__.A instance at 0xb70f6fcc> <type 'instance'>
 
     With debug=True, the function will print out the exception
-    encountered when doing eval(s), and this may point out
-    problems with, e.g., imports in the calling code (insufficient
-    variables in globals).
+    encountered when doing eval(s, globals_, locals_), and this may
+    point out problems with, e.g., imports in the calling code
+    (insufficient variables in globals_).
 
     Note: if the string argument is the name of a valid Python
     class (type), that class will be returned. For example,
     >>> str2obj('list')  # returns class list
     <type 'list'>
     """
+    if globals_ is None:
+        globals_ = globals()
+    if locals_ is None:
+        locals_ = locals()
+    
     try:
         b = str2bool(s)
         return b
     except (ValueError, TypeError), e:
         # s is not a boolean value, try eval(s):
         try:
-            b = eval(s, globals, locals)
+            b = eval(s, globals_, locals_)
             return b
         except Exception, e:
             if debug:
@@ -291,7 +310,8 @@ def str2type(value):
     conversion from a string to the right user-defined type cannot
     be done by the function returned from str2type.
 
-    Examples::
+    Examples:
+    
     >>> f = str2type((1,4,3))
     >>> f.__name__
     'tuple'
@@ -321,15 +341,18 @@ def str2type(value):
         return str
     
 
-def interpret_as_callable_or_StringFunction(s, iv, globals=globals()):
+def interpret_as_callable_or_StringFunction(s, iv, globals_=None):
     """
     Return a callable object if s is the name of such an
     object, otherwise turn s to a StringFunction with
     iv as the name of the independent variable.
-    Used by the read_cml function.
+    Used by the read_cml function. The globals_ variable is set
+    equal to the module's globals() by default (None).
     """
+    if globals_ is None:
+        globals_ = globals()
     try:
-        evaled_s = eval(s, globals)
+        evaled_s = eval(s, globals_)
         if callable(evaled_s):
             return evaled_s
         else:
@@ -340,7 +363,7 @@ def interpret_as_callable_or_StringFunction(s, iv, globals=globals()):
             if isinstance(iv, str):  # single indep. variable?
                 iv = [iv]
             func = StringFunction(s, independent_variables=iv,
-                                  globals=globals)
+                                  globals=globals_)
         except Exception, e:
             raise ValueError(
                 '%s\n"%s" must be a function name, instance creation, \
@@ -348,7 +371,7 @@ def interpret_as_callable_or_StringFunction(s, iv, globals=globals()):
         return func
 
 
-def read_cml_func(option, default_func, iv='t', globals=globals()):
+def read_cml_func(option, default_func, iv='t', globals_=None):
     """
     Locate --option on the command line (sys.argv) and find
     the corresponding value (next sys.argv element).
@@ -362,12 +385,14 @@ def read_cml_func(option, default_func, iv='t', globals=globals()):
     StringFunction object) is returned. For StringFunctions the iv
     argument specifies the name(s) of the independent variable(s).
     Parameters to StringFunction objects are not supported.  The
-    globals argument are used for eval(callable_name) or when
+    globals_ argument are used for eval(callable_name) or when
     creating the  StringFunction object.
 
     Note that this function always returns a callable object,
     supposed to be a user-defined function.
     """
+    if globals_ is None:
+        globals_ = globals()
     if option in sys.argv:
         i = sys.argv.index(option)
         try:
@@ -377,7 +402,7 @@ def read_cml_func(option, default_func, iv='t', globals=globals()):
                 'no value after option %s on the command line' \
                 % option)
         value = interpret_as_callable_or_StringFunction\
-                (value, iv, globals=globals)
+                (value, iv, globals=globals_)
     else:
         value = default_func
     return value
@@ -446,6 +471,71 @@ def sorted_os_path_walk(root, func, arg):
             sorted_os_path_walk(name, func, arg) # recurse into directory
 
 
+def subst(patterns, replacements, filenames,
+          pattern_matching_modifiers=0):
+    """
+    Replace a set of patterns by a set of replacement strings (regular
+    expressions) in a series of files.
+    The function essentially performs::
+
+      for filename in filenames:
+          file_string = open(filename, 'r').read()
+          for pattern, replacement in zip(patterns, replacements):
+              file_string = re.sub(pattern, replacement, file_string)
+
+    A copy of the original file is taken, with extension `.old~`.
+
+    ==========================  ======================================
+    ==========================  ======================================
+    patterns                    string or list of strings (regex)
+    replacements                string or list of strings (regex)
+    filenames                   string or list of strings
+    pattern_matching_modifiers  re.DOTALL, re.MULTILINE, etc., same
+                                syntax as for re.compile
+    ==========================  ======================================
+    """
+    # if some arguments are strings, convert them to lists:
+    if isinstance(patterns, basestring):
+        patterns = [patterns]
+    if isinstance(replacements, basestring):
+        replacements = [replacements]
+    if isinstance(filenames, basestring):
+        filenames = [filenames]
+
+    # pre-compile patterns:
+    cpatterns = [re.compile(pattern, pattern_matching_modifiers) \
+                 for pattern in patterns]
+    modified_files = dict([(p,[]) for p in patterns])  # init
+    messages = []   # for return info
+
+    for filename in filenames:
+        if not os.path.isfile(filename):
+            raise IOError('%s is not a file!' % filename)
+        f = open(filename, 'r');
+        filestr = f.read()
+        f.close()
+
+        for pattern, cpattern, replacement in \
+            zip(patterns, cpatterns, replacements):
+            if cpattern.search(filestr):
+                filestr = cpattern.sub(replacement, filestr)
+                shutil.copy2(filename, filename + '.old~') # backup
+                f = open(filename, 'w')
+                f.write(filestr)
+                f.close()
+                modified_files[pattern].append(filename)
+
+    # make a readable return string with substitution info:
+    for pattern in sorted(modified_files):
+        if modified_files[pattern]:
+            replacement = replacements[patterns.index(pattern)]
+            messages.append('%s replaced by %s in %s' % \
+                                (pattern, replacement, 
+                                 ', '.join(modified_files[pattern])))
+
+    return ', '.join(messages) if messages else 'no substitutions'
+
+
 # class Command has now been replaced by the standard functools.partial
 # function in Python v2.5 and later:
 
@@ -454,7 +544,7 @@ class Command:
     Alternative to lambda functions.
 
     This class should with Python version 2.5 and later be replaced
-    by the "partial" class in the standard module functools.
+    by functools.partial.
     However, you cannot simply do a::
 
       Command = functools.partial
@@ -1032,26 +1122,6 @@ def hardware_info():
     result['identifier'] = platform.platform()
     return result
 
-def checkmathfunc(f, args):
-    """
-    Investigate the (mathematical) function f(*args):
-
-      - Check that f works with scalar and array arguments
-
-      - Check if args are scalars and if basic functions in
-        f apply Numerical Python versions and not math
-    """
-    import numarray, Numeric
-    # local import:
-    __import__('Numeric', globals(), locals(), dir(Numeric))
-    # could time f with scalar arguments
-    # local import of math
-    # time f again to see if f was faster
-
-    # run f with 1D and 3D arrays, compare result with
-    # corresponding loops and scalar evaluations
-    raise NotImplementedError('NOT IMPLEMENTED YET')
-
 
 def memusage(_proc_pid_stat = '/proc/%s/stat'%(os.getpid())):
     """
@@ -1238,7 +1308,7 @@ class DoNothing(object):
     
     For example, say a plot function returns a plot object that
     is used widely in a code to create windows with visualizations
-    on the screen, and you want to turn off all these visualizations::
+    on the screen, and you want to turn off all these visualizations:
 
     >>> from scitools.misc import DoNothing
     >>> plot = DoNothing('Plotting turned off')
@@ -1267,19 +1337,86 @@ class DoNothing(object):
         return self
     def next(self):
         raise StopIteration()
-        
+    
+
+def fix_latex_command_regex(pattern, application='match'):
+    """
+    Given a pattern for a regular expression match or substitution,
+    the function checks for problematic patterns commonly
+    encountered when working with LaTeX texts, namely commands
+    starting with a backslash. 
+
+    For a pattern to be matched or substituted, and extra backslash is
+    always needed (either a special regex construction like \w leads
+    to wrong match, or \c leads to wrong substitution since \ just
+    escapes c so only the c is replaced, leaving an undesired
+    backslash). For the replacement pattern in a substitutions, specified
+    by the application='replacement' argument, a backslash
+    before any of the characters abfgnrtv must be preceeded by an
+    additional backslash.
+
+    The application variable equals 'match' if pattern is used for
+    a match and 'replacement' if pattern defines a replacement
+    regex in a re.sub command.
+
+    Caveats: let pattern just contain LaTeX commands, not combination
+    of commands and other regular expressions (\s, \d, etc.) as the
+    latter will end up with an extra undesired backslash.
+
+    Here are examples on failures:
+
+    >>> re.sub(r'\begin\{equation\}', r'\[', r'\begin{equation}')
+    '\\begin{equation}'
+    >>> # match of mbox, not \mbox, and wrong output:
+    >>> re.sub(r'\mbox\{(.+?)\}', r'\fbox{\g<1>}', r'\mbox{not}')
+    '\\\x0cbox{not}'
+
+    Here are examples on using this function:
+
+    >>> from scitools.misc import fix_latex_command_regex as fix
+    >>> pattern = fix(r'\begin\{equation\}', application='match')
+    >>> re.sub(pattern, r'\[', r'\begin{equation}')
+    '\\['
+    >>> pattern = fix(r'\mbox\{(.+?)\}', application='match')
+    >>> replacement = fix(r'\fbox{\g<1>}', application='replacement')
+    >>> re.sub(pattern, replacement, r'\mbox{not}')
+    '\\fbox{not}'
+
+    Avoid mixing LaTeX commands and ordinary regular expression
+    commands, e.g.:
+
+    >>> pattern = fix(r'\mbox\{(\d+)\}', application='match')
+    >>> pattern
+    '\\\\mbox\\{(\\\\d+)\\}'
+    >>> re.sub(pattern, replacement, r'\mbox{987}')
+    '\\mbox{987}'  # no substitution, no match
+    """
+    import string
+    problematic_letters = string.ascii_letters if application == 'match' \
+                          else 'abfgnrtv'
+
+    for letter in problematic_letters:
+        problematic_pattern = '\\' + letter
+
+        if letter == 'g' and application == 'replacement':
+            # no extra \ for \g<...> in pattern
+            if r'\g<' in pattern:
+                continue
+
+        ok_pattern = '\\\\' + letter
+        if problematic_pattern in pattern and not ok_pattern in pattern:
+            pattern = pattern.replace(problematic_pattern, ok_pattern)
+    return pattern
+
+
+
 if __name__ == '__main__':
-    task = 'Command'
     try:
         task = sys.argv[1]
     except:
-        pass
+        task = ''
 
-    if task == 'Command':
-        c = Command(f, 2.3, 2.1, max=0, min=-1.2)
-        print 'Command.args=',c.args,'Command.kwargs=',c.kwargs
-        c()         # call f(2.3, 2.1, 0, -1.2)
-    elif task == 'debugregex':
+    if task == 'debugregex':
         r = r'<(.*?)>'
         s = '<r1>is a tag</r1> and <s1>s1</s1> is too.'
         print debugregex(r,s)
